@@ -1,4 +1,12 @@
 #!/usr/bin/env python3
+
+# Allow direct execution
+import os
+import sys
+
+sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
+
+
 import optparse
 
 
@@ -7,7 +15,7 @@ def read(fname):
         return f.read()
 
 
-# Get the version from yt_dlp/version.py without importing the package
+# Get the version without importing the package
 def read_version(fname):
     exec(compile(read(fname), fname, 'exec'))
     return locals()['__version__']
