@@ -563,6 +563,7 @@ from .funimation import (
 )
 from .funk import FunkIE
 from .fusion import FusionIE
+from .fuyintv import FuyinTVIE
 from .gab import (
     GabTVIE,
     GabIE,
@@ -836,6 +837,7 @@ from .livestream import (
     LivestreamOriginalIE,
     LivestreamShortenerIE,
 )
+from .livestreamfails import LivestreamfailsIE
 from .lnkgo import (
     LnkGoIE,
     LnkIE,
@@ -1329,6 +1331,7 @@ from .puhutv import (
     PuhuTVIE,
     PuhuTVSerieIE,
 )
+from .premiershiprugby import PremiershipRugbyIE
 from .presstv import PressTVIE
 from .projectveritas import ProjectVeritasIE
 from .prosiebensat1 import ProSiebenSat1IE
@@ -1509,6 +1512,7 @@ from .scte import (
     SCTEIE,
     SCTECourseIE,
 )
+from .scrolller import ScrolllerIE
 from .seeker import SeekerIE
 from .senategov import SenateISVPIE, SenateGovIE
 from .sendtonews import SendtoNewsIE
@@ -1630,7 +1634,10 @@ from .srgssr import (
 from .srmediathek import SRMediathekIE
 from .stanfordoc import StanfordOpenClassroomIE
 from .startv import StarTVIE
-from .steam import SteamIE
+from .steam import (
+    SteamIE,
+    SteamCommunityBroadcastIE,
+)
 from .storyfire import (
     StoryFireIE,
     StoryFireUserIE,
@@ -1928,7 +1935,10 @@ from .vice import (
 from .vidbit import VidbitIE
 from .viddler import ViddlerIE
 from .videa import VideaIE
-from .videocampus_sachsen import VideocampusSachsenIE
+from .videocampus_sachsen import (
+    VideocampusSachsenIE,
+    ViMPPlaylistIE,
+)
 from .videodetective import VideoDetectiveIE
 from .videofyme import VideofyMeIE
 from .videomore import (
