@@ -1,19 +1,20 @@
 import base64
-import re
 import json
-import zlib
-
+import re
+import urllib.request
 import xml.etree.ElementTree
+import zlib
 from hashlib import sha1
-from math import pow, sqrt, floor
+from math import floor, pow, sqrt
+
 from .common import InfoExtractor
 from .vrv import VRVBaseIE
+from ..aes import aes_cbc_decrypt
 from ..compat import (
     compat_b64decode,
     compat_etree_fromstring,
     compat_str,
     compat_urllib_parse_urlencode,
-    compat_urllib_request,
     compat_urlparse,
 )
 from ..utils import (
@@ -22,8 +23,8 @@ from ..utils import (
     extract_attributes,
     float_or_none,
     format_field,
-    intlist_to_bytes,
     int_or_none,
+    intlist_to_bytes,
     join_nonempty,
     lowercase_escape,
     merge_dicts,
@@ -34,9 +35,6 @@ from ..utils import (
     try_get,
     xpath_text,
 )
-from ..aes import (
-    aes_cbc_decrypt,
-)
 
 
 class CrunchyrollBaseIE(InfoExtractor):
@@ -259,7 +257,7 @@ class CrunchyrollIE(CrunchyrollBaseIE, VRVBaseIE):
     }
 
     def _download_webpage(self, url_or_request, *args, **kwargs):
-        request = (url_or_request if isinstance(url_or_request, compat_urllib_request.Request)
+        request = (url_or_request if isinstance(url_or_request, urllib.request.Request)
                    else sanitized_Request(url_or_request))
         # Accept-Language must be set explicitly to accept any language to avoid issues
         # similar to https://github.com/ytdl-org/youtube-dl/issues/6797.
